
/************************ PRODUCT VALIDATION  ******************
 *
 *      NAME: AdverseEventsDistribution_AE001.sas
 *    REPORT: Adverse Event Distribution JMPC7.1
 *   PURPOSE: Adverse Event Distribution Validation Program for Nicardipine Study
 *   DEFECTS: 
 *     NOTES: Use Dictornary-Derived Term,BodySystem or Organ Class, 
 *     NOTES: Use Actual Treatment, All event types , single event counts
 *     NOTES: NO Discrepancy found between JMPC Results and Validation Results

 *****************************************************************/
title1 'AdverseEventsDistribution_AE001.sas: Adverse Event Distribution Validation Program';
title2 'Use BodySystem or Organ Class, Actual, All event, single event counts';

libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

data adsl;
 set adam.adsl;
 if saffl='Y' and trt01p ne 'Screen Failure';
 if trt01p ne '' then do; trtsrt=trt01p; output; end;
 if trt01p ne '' then do; trtsrt='Total'; output; end;
run;

data ae;
 set sdtm.ae;
run;

data ae_adsl;
 merge adam.adsl(in=a where=(saffl='Y' and trt01p ne 'Screen Failure')) ae(in=b);
 by usubjid;
 if a & b;

 if trt01p ne '' then do; trtsrt=trt01p; output; end;
 if trt01p ne '' then do; trtsrt='Total'; output; end;
run;


*** Get Tabulate counts/percents ***;
proc sort data=ae_adsl out=ae_adsl2 nodupkey;
 by trtsrt usubjid aebodsys aedecod;
run;

proc freq data=ae_adsl2 noprint;
 by trtsrt;
 tables aebodsys*aedecod/out=freq(drop=percent);
run;

proc freq data=adsl noprint;
 tables trtsrt/out=denom(rename=(count=denom));
run;

data freq2;
 merge freq(in=a) denom;
 by trtsrt;
 if a;
 nper=put(count,3.)||' ('||strip(round((count/denom)*100,.1))||'%)';
run;

proc sort data=freq2; by aebodsys aedecod; run;
proc transpose data=freq2 out=t_freq(drop=_name_);
 by aebodsys aedecod;
 var nper;
 id trtsrt;
run; 

**** Use Proc Report to write the lab stats Tables to file;
options nodate nonumber missing = ' ';

filename pdfOutF "&OUTPUTD/AdverseEventsDistribution_AE001.pdf";

ods escapechar='#';
ods pdf style =htmlblue file=pdfOutF;

proc report data=t_freq
	nowindows
	split="|";
	
	columns aebodsys aedecod NIC__15 Placebo Total;

	define aebodsys /order width =19 "Body System or Organ Class";
	define aedecod  /order width =19 "Dictionary-Derived Term";
	define NIC__15  /display center width=19 "NIC 15";
	define Placebo  /display center width=19 "Placebo";
	define Total    /display center width=19 "Total";

	compute after aebodsys;
		line '#{newline}';
	endcomp;

title3 j=c 'Adverse Events Distribution Counts Table';
run;

ods pdf close;

*** Dataset to use for distributions ***;
data ae_dist;
 merge adam.adsl(in=a where=(saffl='Y' and trt01p ne 'Screen Failure')) ae(in=b);
 by usubjid;
 if a;
run;

proc sort data=ae_dist out=dists;
 by trt01p usubjid aebodsys aedecod descending aeser descending aesev aestdy;
run;

data dists2;
 set dists;
 by trt01p usubjid aebodsys aedecod;
 if first.aedecod;
run;

libname outdata "&OUTPUTD";
data outdata.AdverseEventsDistribution_AE001;
 set dists2(keep=trt01p usubjid aebodsys aedecod aeser aesev aestdy aerel aeacn aeout);
run;

