
/************************ PRODUCT VALIDATION  ******************
 *
 *      NAME: FindingsBoxPlots_LB001.sas
 *    REPORT: Laboratory Test Results Box Plots JMPC 7.1
 *   PURPOSE: Laboratory Test Results Validation Program for Nicardipine study
 *   DEFECTS: 
 *     NOTES: Actual treatment, Change from baseline
 *     Notes: SAFETY POPULATION
 *     NOTES: Same Results as JMPC for Nicardipine study 
 *****************************************************************/
title1 'FindingsBoxPlots_LB001.sas: Laboratory Test Results Box Plots Validation Program';
title2 'Use Actual treatment, change from baseline';


*** Bring in datasets ***;
libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

*** Subset ADSL on safety population ***;
data adsl;
 set adam.adsl;
 where saffl='Y' and trt01p ne 'Screen Failure';
run;

data lb;
 set sdtm.lb;
run;

*** Merge ADSL and LB ***;
data adsl_lb;
 merge adsl(in=a) lb(in=b);
 by usubjid;
 if a & b;
run;

proc sort data=adsl_lb; by usubjid lbtestcd lbtest trt01p visitnum lbblfl; run;

*** Get baseline ***;
proc sort data=adsl_lb out=base; by usubjid lbtestcd lbtest trt01p visitnum lbdy; where lbblfl='Y'; run;
*** Take the mean per day if multiple records in same time point, then take last pre-treatment record***;
proc means data=base noprint;
 by usubjid lbtestcd lbtest trt01p visitnum lbdy;
 var lbstresn;
 output out=base2 mean=base;
run;

data base3;
 set base2;
 by usubjid lbtestcd lbtest trt01p visitnum lbdy;
 if last.lbtestcd;
 keep usubjid lbtestcd base;
run;

*** Merge baseline back in ***;
proc sort data=adsl_lb; by usubjid lbtestcd; run;
data adsl_lb2;
 merge adsl_lb base3;
 by usubjid lbtestcd;
 chg = lbstresn - base;
 if visitnum ne . and lbblfl ne 'Y';
run;

proc sort data=adsl_lb2; by usubjid lbtestcd lbtest trt01p visitnum; run;
*** Take the mean if multiple records in same time point ***;
proc means data=adsl_lb2 noprint;
 by usubjid lbtestcd lbtest trt01p visitnum;
 var chg;
 output out=adsl_lb3 mean=mean_chg;
run;

*** Stats for lab tables ***;
proc sort data=adsl_lb3; by lbtest lbtestcd trt01p visitnum; run;
proc means data=adsl_lb3 noprint;
 by lbtest lbtestcd trt01p visitnum;
 var mean_chg;
 output out=lb_means n=n mean=mean std=std min=min median=median max=max;
run;

*** Format stats into a table similar to JMP report ***;
data lb_means2;
 set lb_means;
 an = put(n,3.);
 bmean = put(mean,10.2);
 cstd = put(std,10.2);
 dmin = put(min,10.2);
 emed = put(median,10.2);
 fmax = put(max,10.2);
run;

proc transpose data=lb_means2 out=t_means;
 by lbtest trt01p;
 var an bmean cstd dmin emed fmax;
 id visitnum;
run;

data t_means2;
 length stat $10;
 set t_means;
 if _name_='an' then stat ='N';
 if _name_='bmean' then stat='Mean';
 if _name_='cstd' then stat='Std Dev';
 if _name_='dmin' then stat='Min';
 if _name_='emed' then stat='Median';
 if _name_='fmax' then stat='Max';
run;

**** Use Proc Report to write the lab stats Tables to file;
options nodate nonumber missing = ' ';

filename pdfOutF "&OUTPUTD/FindingsBoxPlots_LB001.pdf";

ods escapechar='#';
ods pdf style =htmlblue file=pdfOutF;

proc report data=t_means2
	nowindows
	split="|";
	
	columns lbtest trt01p _name_ stat _2 _3 _4 _5 _6 _7 _8 _9 _10 _11 _12 _13 _14;

	define _name_   /order order=internal noprint;
	define lbtest   /order width =8 "Lab Test or Examination Name";
	define trt01p   /order width =7 "Planned Treatment for Period 01";
	define stat     /order width =7 "Statistic";
	define _2    	/display center width=6 "Visit 2";
	define _3    	/display center width=6 "Visit 3";
	define _4    	/display center width=6 "Visit 4";
	define _5    	/display center width=6 "Visit 5";
	define _6    	/display center width=6 "Visit 6";
	define _7    	/display center width=6 "Visit 7";
	define _8    	/display center width=6 "Visit 8";
	define _9    	/display center width=6 "Visit 9";
	define _10    	/display center width=6 "Visit 10";
	define _11    	/display center width=6 "Visit 11";
	define _12    	/display center width=6 "Visit 12";
	define _13    	/display center width=6 "Visit 13";
	define _14    	/display center width=6 "Visit 14";

	compute after lbtest;
		line '#{newline}';
	endcomp;

title3 j=c 'Change from Baseline Summary Statistic Tables';
run;

ods pdf close;

*** Create dataset for boxplot ***;
proc sort data=adsl_lb3; by usubjid visitnum; run;
proc transpose data=adsl_lb3 out=boxplot_data(drop=_name_);
 by usubjid visitnum trt01p;
 var mean_chg;
 id lbtestcd;
run;

libname outdata "&OUTPUTD";
data outdata.FindingsBoxPlots_LB001;
 set boxplot_data;
run;
