/************************ PRODUCT VALIDATION ******************
 *
 *      NAME: FindingsTimeTrends_LB001.sas
 *    REPORT: Findings Time Trends JMPC 7.1
 *   PURPOSE: Findings Time Trends Validation Program For Nicardipine study
 *   DEFECTS: 
 *     NOTES: LB, SAFETY Popluation,  Actural Treatment, No Normalization,
 *     NOTES: Use Observed_Results
 *     NOTES: Use mean for multiple measurements on the same visitnum
 *     NOTES: Same Results as JMPC
 
 *****************************************************************/



**** specify analysis variable as finding measurements ****;
%let aval = Observed_Result;

title1 'FindingsTimeTrends_LB001.sas: Findings Laboratory Test Results Time Trends Validation Program';
title2 "&aval as finding measurements, No Normalization";


libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

**** Subset ADSL on safety population ****;
data adsl;
	set adam.adsl;
 	where saffl='Y' and trt01p ne 'Screen Failure';
run;

data dm;
	set sdtm.dm (keep=usubjid RFSTDTC RFENDTC);
run;

data adsl; merge adsl (in=inadsl) dm;
	by usubjid;
	if inadsl;
run;

*** Merge ADSL and LB, 64355 obs in lb data and in adsl ****;
data lb; 
	merge adsl(in=inadsl keep=usubjid trt01p trt01pn) sdtm.lb(in=inlb);
	by usubjid;
	if inadsl and inlb;
run;


**** Get lab findings time trends ****;
**** Use mean for multiple measurements on the same VISITNUM ****;

proc sql;
	create table LB_data as
	select  distinct usubjid, lbtestcd,visitnum, trt01p, mean(lbstresn) as &aval
	from lb
	group by usubjid, lbtestcd, visitnum
    order by usubjid, lbtestcd, visitnum;
quit;

**** Create dataset for Findings Time Trends ****;
proc sort data=LB_data; by usubjid visitnum lbtestcd; run;
proc transpose data=LB_data out=LB_data_rec (drop= _name_);
by usubjid visitnum ;
var &aval;
id lbtestcd;
run;


libname outdata "&OUTPUTD";
data outdata.FindingsTimeTrends_LB001;
 set LB_data_rec;
run;



**** Compute averages for each time point over whole dataset ****;
proc sort data=LB_data;
by lbtestcd visitnum trt01p;
run;

proc means data=LB_data  noprint;
by  lbtestcd VISITNUM  trt01p ;
var &aval;
output out=_stdm mean=&aval;
run;

options nodate nonumber missing = ' ';

filename pdfOutF "&OUTPUTD/FindingsTimeTrends_LB001.pdf";

ods _all_ close;
ods escapechar='#';
ods pdf style =htmlblue file=pdfOutF
	 startpage=no;;
ods graphics/ reset=all height=4in width=7in;

title3 "Average &aval vs Visit Number ";
title3;

proc sgplot data=_stdm;
	series x=visitnum  y=&aval /group=trt01p;
    by lbtestcd;
	yaxis 
		display =(noticks)
		label ="  &aval ";
	xaxis 
		label = 'Visit Number'
		values = (0 to 14 by 1);
	keylegend /location=outside position=right;
run;

proc sgplot data=_stdm;
 vbar visitnum / response=_freq_
 group=trt01p groupdisplay=cluster
 dataskin=pressed
 baselineattrs=(thickness=0);
 xaxis label= 'Visit Number';
 yaxis label= 'Counts';
 by lbtestcd;
run;
ods pdf close;
